/***********************************************************************************************************************************
Check Command
***********************************************************************************************************************************/
#ifndef COMMAND_CHECK_CHECK_H
#define COMMAND_CHECK_CHECK_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Perform standard checks
FN_EXTERN void cmdCheck(void);

#endif
